#ifndef EMPLOYEE_H
#define EMPLOYEE_H

#include <iostream>
#include <string>

/**  Abstrakte Basisklasse eines allgemeinen Angestellten einer Verkaufsstelle
*/
class Employee
{
    public:
        /** Parameter constructor
         @param[in]  name  Name des Angestellten
        */
        explicit Employee(const std::string& name); // explicit suggested by Intel compiler for a on-element parameter list in constructor

        Employee(Employee const&)            = default;     // copy constructor
        Employee(Employee&&)                 = default;     // move constructor
        Employee& operator=(Employee const&) = default;     // copy assignment operator
        Employee& operator=(Employee &&)     = default;     // move assignment operator

        /** Default destructor */
        virtual ~Employee();

        /**  Gibt die Daten der aktuellen Instanz aus.
           @param[in,out] s  Ausgabestrom
        */
        virtual void print(std::ostream& s) const;

        /**  Berechnet das Gehalt.
           @return  Gehalt.
        */
        virtual float payment() const = 0;   // rein virtuell
//            {return 0.0f; }                // da war die Methode nur virtuell

        /**  Rueckgabe der Anzahl der Instanzen von Employee und abgleiteten Klassen.
           @return  Anzahl.
        */
        int get_Counter() const {return _counter;}

        /**  Lesezugriff auf Namen.
           @return  Name des Angestellten.
        */
        std::string get_Name() const {return _name;}

    protected:
    private:
        std::string _name;        //!< Name der Person
        static int _counter; //!<  e i n   Zaehler fuer alle Instanzen
};

#endif // EMPLOYEE_H
