#ifndef SALESPERSON_H
#define SALESPERSON_H

#include "worker.h"
#include <iostream>
#include <string>

/**      Verkaeufer in einer Verkaufsstelle
*/
class SalesPerson : public Worker
{
    public:
        /** Parameter constructor
         @param[in]  name  Name des Angestellten
         @param[in]  hours Arbeitsstunden
         @param[in]  wageHour  Stundenlohn
         @param[in]  commission Umsatz
         @param[in]  percent  Umsatzbeteiligung in Prozent
        */
        SalesPerson(const std::string& name, int hours, float wageHour,
                    float commission, float percent);

        SalesPerson(SalesPerson const&)            = default;     // copy constructor
        SalesPerson(SalesPerson&&)                 = default;     // move constructor
        SalesPerson& operator=(SalesPerson const&) = default;     // copy assignment operator
        SalesPerson& operator=(SalesPerson &&)     = default;     // move assignment operator

        /** Default destructor */
        virtual ~SalesPerson() override;

        /**  Gibt die Daten der aktuellen Instanz aus.
           @param[in,out] s  Ausgabestrom
        */
        void print(std::ostream& s) const override;

        /**  Berechnet das Gehalt.
           @return  Gehalt.
        */
        float payment() const override
         {return Worker::payment() + _commission*_percent;}

    protected:
    private:
        float _commission; //!< Umsatz
        float _percent; //!< Umsatzbeteiligung in Prozent
};

#endif // SALESPERSON_H
